==> vlc-3.0.0-rc8.tar.xz: vlc-3.0.0-rc8/modules/demux/hls/HLSManager.hpp <==
/*
 * HLSManager.hpp
 *****************************************************************************
 * Copyright © 2015 - VideoLAN and VLC authors
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/
#ifndef HLSMANAGER_HPP
#define HLSMANAGER_HPP

#include "../adaptive/PlaylistManager.h"
#include "../adaptive/logic/AbstractAdaptationLogic.h"
#include "playlist/M3U8.hpp"

namespace hls
{
    using namespace adaptive;

    class HLSManager : public PlaylistManager
    {
        public:
            HLSManager( demux_t *,
                        AuthStorage *,
                        playlist::M3U8 *,
                        AbstractStreamFactory *,
                        logic::AbstractAdaptationLogic::LogicType type );
            virtual ~HLSManager();
            static bool isHTTPLiveStreaming(stream_t *);

        protected:
            virtual mtime_t getFirstPlaybackTime() const;
    };

}

#endif // HLSMANAGER_HPP

==> vlc-3.0.0-20160606.tar.xz: vlc-3.0.0-20160606/modules/demux/hls/HLSManager.hpp <==
/*
 * HLSManager.hpp
 *****************************************************************************
 * Copyright © 2015 - VideoLAN and VLC authors
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/
#ifndef HLSMANAGER_HPP
#define HLSMANAGER_HPP

#include "../adaptive/PlaylistManager.h"
#include "../adaptive/logic/AbstractAdaptationLogic.h"
#include "playlist/M3U8.hpp"

namespace hls
{
    using namespace adaptive;

    class HLSManager : public PlaylistManager
    {
        public:
            HLSManager( demux_t *, playlist::M3U8 *,
                        AbstractStreamFactory *,
                        logic::AbstractAdaptationLogic::LogicType type );
            virtual ~HLSManager();
            static bool isHTTPLiveStreaming(stream_t *);

        protected:
            virtual mtime_t getFirstPlaybackTime() const;
    };

}

#endif // HLSMANAGER_HPP
